@@ -30,6 +30,7 @@
 #include <abstractmetalang.h>
 #include "generator.h"
 
+class QtDocParser;
 class AbstractMetaFunction;
 class AbstractMetaClass;
 class QXmlStreamReader;
@@ -159,6 +160,9 @@ QTextStream& operator<<(QTextStream& s, const QtXmlToSphinx::Table &table);
 class GENRUNNER_API QtDocGenerator : public Generator
 {
 public:
+    QtDocGenerator();
+    ~QtDocGenerator();
+
     QString libSourceDir() const
     {
         return m_libSourceDir;
@@ -180,7 +184,7 @@ public:
 
 protected:
     QString fileNameForClass(const AbstractMetaClass* cppClass) const;
-    void generateClass(QTextStream& s, const AbstractMetaClass* cppClass);
+    void generateClass(QTextStream& s, const AbstractMetaClass* metaClass);
     void finishGeneration();
 
     void writeFunctionArguments(QTextStream&, const AbstractMetaFunction*, Options) const {}
@@ -191,11 +195,10 @@ private:
 
     void writeFields(QTextStream &s, const AbstractMetaClass *cppClass);
     void writeArguments(QTextStream &s, const AbstractMetaClass *cppClass, const AbstractMetaFunction *func);
-    void writeFunctionBrief(QTextStream &s, const AbstractMetaClass *cppClass, const AbstractMetaFunction *cppFunction);
     void writeFunctionSignature(QTextStream& s, const AbstractMetaClass* cppClass, const AbstractMetaFunction* func);
     void writeFunction(QTextStream& s, bool writeDoc, const AbstractMetaClass* cppClass, const AbstractMetaFunction* func);
     void writeFunctionParametersType(QTextStream &s, const AbstractMetaClass *cppClass, const AbstractMetaFunction* func);
-    void writeFunctionList(QTextStream &se, const QString &content, const AbstractMetaClass *cppClass);
+    void writeFunctionList(QTextStream& s, const AbstractMetaClass* cppClass);
     void writeParamerteType(QTextStream &s, const AbstractMetaClass *cppClass, const AbstractMetaArgument *arg);
 
     void writeConstructors(QTextStream &s, const AbstractMetaClass *cppClass);
@@ -205,14 +208,14 @@ private:
 
 
     QString parseArgDocStyle(const AbstractMetaClass *cppClass, const AbstractMetaFunction *func);
-    QString parseFunctionDeclaration(const QString &data, const AbstractMetaClass *cppClass);
     QString translateToPythonType(const AbstractMetaType *type, const AbstractMetaClass *cppClass);
 
     QString m_docDataDir;
     QString m_libSourceDir;
     QString m_codeSnippetDir;
     QStringList m_functionList;
-    Documentation m_moduleDoc;
+    QMap<QString, QStringList> m_packages;
+    QtDocParser* m_docParser;
 };
 
 #endif // DOCGENERATOR_H
